@@ -12,18 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from newrelic_telemetry_sdk.batch import EventBatch, SpanBatch
 from newrelic_telemetry_sdk.client import (
-    SpanClient,
-    MetricClient,
     EventClient,
     HTTPError,
+    LogClient,
+    MetricClient,
+    SpanClient,
 )
-from newrelic_telemetry_sdk.span import Span
-from newrelic_telemetry_sdk.metric import GaugeMetric, CountMetric, SummaryMetric
 from newrelic_telemetry_sdk.event import Event
-from newrelic_telemetry_sdk.metric_batch import MetricBatch
-from newrelic_telemetry_sdk.batch import SpanBatch, EventBatch
 from newrelic_telemetry_sdk.harvester import Harvester
+from newrelic_telemetry_sdk.log import Log, NewRelicLogFormatter
+from newrelic_telemetry_sdk.metric import CountMetric, GaugeMetric, SummaryMetric
+from newrelic_telemetry_sdk.metric_batch import MetricBatch
+from newrelic_telemetry_sdk.span import Span
 
 try:
     from newrelic_telemetry_sdk.version import version as __version__
@@ -35,11 +37,14 @@ __all__ = (
     "SpanClient",
     "MetricClient",
     "EventClient",
+    "LogClient",
     "Span",
     "GaugeMetric",
     "CountMetric",
     "SummaryMetric",
     "Event",
+    "Log",
+    "NewRelicLogFormatter",
     "MetricBatch",
     "SpanBatch",
     "EventBatch",
